<?php
/**
 * +----------------------------------------------------------------------
 * | 配置信息控制器
 * +----------------------------------------------------------------------
 *                      .::::.
 *                    .::::::::.            | AUTHOR: siyu
 *                    :::::::::::           | EMAIL: 407593529@qq.com
 *                 ..:::::::::::'           | DATETIME: 2020/01/21
 *             '::::::::::::'
 *                .::::::::::
 *           '::::::::::::::..
 *                ..::::::::::::.
 *              ``::::::::::::::::
 *               ::::``:::::::::'        .:::.
 *              ::::'   ':::::'       .::::::::.
 *            .::::'      ::::     .:::::::'::::.
 *           .:::'       :::::  .:::::::::' ':::::.
 *          .::'        :::::.:::::::::'      ':::::.
 *         .::'         ::::::::::::::'         ``::::.
 *     ...:::           ::::::::::::'              ``::.
 *   ```` ':.          ':::::::::'                  ::::..
 *                      '.:::::'                    ':'````..
 * +----------------------------------------------------------------------
 */
namespace app\admin\controller;

// 引入框架内置类
use think\facade\Request;
// 引入表格和表单构建器
use app\common\builder\FormBuilder;
// 引入阿里云SDK
use AlibabaCloud\Client\AlibabaCloud;
use AlibabaCloud\Client\Exception\ClientException;
use AlibabaCloud\Client\Exception\ServerException;

class Config extends Base
{
    // 邮件配置
    public function email(){
        $smtp = \app\common\model\Config::where('inc_type','=','smtp')
            ->select();
        $info = convert_arr_kv($smtp,'name','value');

        return FormBuilder::getInstance()
            ->addText('smtp_server', '服务器')
            ->addText('smtp_port', 'SMTP端口')
            ->addText('email_id', '发件人')
            ->addText('smtp_user', '发件邮箱')
            ->addPassword('smtp_pwd', '身份验证码')
            ->addText('regis_smtp_enable', '标题')
            ->addText('test_eamil', '测试邮箱')
            ->addEditor('test_eamil_info', '测试邮件内容', '', '', '100')
            ->setFormData($info)
            ->setFormUrl(url('emailPost'))
            ->hideBtn('back')
            ->addBtn('<button type="button" id="test_email" class="btn btn-flat btn-info ">测试发送</button>')
            ->setExtraHtml($this->getEmailExtraHtml(), 'content_bottom')
            ->setPageTips('<div style="line-height: 32px;float: left">系统采用SMTP方式发送邮件</div>', 'success', 'search')
            ->hideShowAll()
            ->fetch();
    }

    // 邮件配置保存
    public function emailPost()
    {
        if (Request::isPost()) {
            $data = Request::post();
            foreach ($data as $k => $v) {
                $result = \app\common\model\Config::where([['name', '=', $k], ['inc_type', '=', 'smtp']])->find();
                if ($k == 'smtp_pwd') {
                    if (!empty($v)) {
                        $result->value = $v;
                    }
                } else {
                    $result->value = $v;
                }
                $result->save();
            }
            $this->success('修改成功', 'email');
        }
    }

    // 测试邮件发送
    public function emailSend(){
        $sender = Request::param('email');
        //检查是否邮箱格式
        if (!is_email($sender)) {
            return json(['error' => 1, 'msg' => '测试邮箱码格式有误']);
        }
        $data = \app\common\model\Config::where('inc_type','smtp')
            ->select();
        $config = convert_arr_kv($data,'name','value');
        $content = $config['test_eamil_info'];
        //所有项目必须填写
        if (empty($config['smtp_server']) || empty($config['smtp_port']) || empty($config['smtp_user']) || empty($config['smtp_pwd'])) {
            return json(['error' => 1, 'msg' => '请完善邮件配置信息！']);
        }

        $send = send_email($sender, '测试邮件',$content);
        if ($send) {
            return ['error' => 0, 'msg' => '邮件发送成功！'];
        } else {
            return ['error' => 1, 'msg' => '邮件发送失败！'];
        }
    }

    // 获取邮件配置额外HTML
    private function getEmailExtraHtml()
    {
        $str = '<script type="text/javascript">
                $("#test_email").click(function () {
                    var url = "' . url('emailSend') . '";
                    var email = $("input[name=\'test_eamil\']").val();
                    $.modal.confirm(\'确定要发送吗？如有修改请先提交保存！\', function () {
                        $.post(url,{email:email},function(result){
                            if(result.error == 0){
                                $.modal.alertSuccess(result.msg);
                            }else{
                                $.modal.alertError(result.msg);
                            }
                          },\'json\');
                    })

                })
            </script>
            ';
        return $str;
    }

    // ==========================================

    // 短信配置
    public function sms(){
        $smtp = \app\common\model\Config::where('inc_type','=','sms')
            ->select();
        $info = convert_arr_kv($smtp,'name','value');

        return FormBuilder::getInstance()
            ->addText('accessKeyId', '短信宝账号', '
                <a href="https://www.smsbao.com/register.jhtml" target="_blank">还没有注册账号？立即注册</a>
                ')
            ->addText('accessKeySecret', '短信宝密码')
            ->addText('signName', '短信宝签名')
            ->addText('templateCode', '模版示例：您的验证码为{$code},3分钟内有效')
            ->addText('test_mobile', '测试手机')
            ->setFormData($info)
            ->setFormUrl(url('smsPost'))
            ->hideBtn('back')
            ->addBtn('<button type="button" id="test_sms" class="btn btn-flat btn-info ">测试发送</button>')
            ->setExtraHtml($this->getSmsExtraHtml(), 'content_bottom')
            ->setPageTips('<div style="line-height: 32px;float: left">系统采用短信宝短信服务发送短信 <a class="btn btn-flat btn-primary m-r-10" href="https://www.smsbao.com/openapi/55.html" target="_blank">查看错误码</a><a class="btn btn-flat btn-primary" href="https://www.smsbao.com/openapi/55.html" target="_blank">使用指引</a></div>', 'success', 'search')
            ->hideShowAll()
            ->fetch();
    }

    // 短信配置保存
    public function smsPost()
    {
        if (Request::isPost()) {
            $data = Request::post();
            foreach ($data as $k => $v) {
                \app\common\model\Config::where([
                    ['name', '=', $k], ['inc_type', '=', 'sms']
                ])
                    ->update(['value' => $v]);
            }
            $this->success('保存成功', 'sms');
        }
    }

    // 测试短信发送
    public function smsSend()
    {
        $data = \app\common\model\Config::where('inc_type', 'sms')->select();
        $config = convert_arr_kv($data, 'name', 'value');

        // 生成验证码
        $code = rand(1000, 9999);
        $statusStr = array(
            "0" => "短信发送成功",
            "-1" => "参数不全",
            "-2" => "服务器空间不支持,请确认支持curl或者fsocket，联系您的空间商解决或者更换空间！",
            "30" => "密码错误",
            "40" => "账号不存在",
            "41" => "余额不足",
            "42" => "帐户已过期",
            "43" => "IP地址限制",
            "50" => "内容含有敏感词"
        );
        $smsapi = "http://api.smsbao.com/";
        $user = $config['accessKeyId']; //短信平台帐号
        $pass = md5($config['accessKeySecret']); //短信平台密码
        $sign = '【'.$config['signName'].'】';
        $content=  $sign.str_replace('{$code}',$code,$config['templateCode']);//要发送的短信内容
        $phone = $config['test_mobile'];//要发送短信的手机号码
        $sendurl = $smsapi."sms?u=".$user."&p=".$pass."&m=".$phone."&c=".urlencode($content);
        $result =file_get_contents($sendurl) ;
        if ($result == 0) {
                return json(['error' => 0, 'msg' => '发送成功']);
        } else {
                return json(['error' => 1, 'msg' => $statusStr[$result]]);
        }
    }

    // 获取短信配置额外HTML
    private function getSmsExtraHtml(){
        $str = '<script type="text/javascript">
                $("#test_sms").click(function () {
                    var url = "' . url('smsSend') . '";
                    var mobile = $("input[name=\'mobile\']").val();
                    $.modal.confirm(\'确定要发送吗？如有修改请先提交保存！\', function () {
                        $.post(url,{mobile:mobile},function(result){
                        if(result.error == 0){
                            $.modal.alertSuccess(result.msg);
                        }else{
                            $.modal.alertError(result.msg);
                        }
                      },\'json\');
                    })
                })
            </script>
            ';
        return $str;
    }

}
